@@ -158,7 +158,7 @@ namespace LinBox
 
 			integer tmp;
 			bool use_neg=false;
-			size_t maxword=0;
+			uint32_t maxword=0;
 			for (size_t i=0;i<n;++i){
 				_domain.convert(tmp,x[i]);
 				if (tmp <0)
@@ -424,7 +424,7 @@ namespace LinBox
 					maxBitSize+=1;
 				}
 				// compute the number of chunk
-				if (maxValue*prime*_matM.coldim() < integer("9007199254740992")){
+				if (maxValue*prime* uint32_t(_matM.coldim()) < integer("9007199254740992")){
 					num_chunks=1;
 					use_neg=false;
 				}
@@ -988,7 +988,7 @@ namespace LinBox
 						LinBox::integer result, tmp;
 						if (use_neg) {
 							result = -ctd[i];
-							result <<= (num_chunks-1)*16;
+							result <<= uint64_t((num_chunks-1)*16);
 #ifdef DEBUG_CHUNK_APPLYM
 							cout << "rcneg: " << result << endl;
 #endif
@@ -1510,11 +1510,10 @@ namespace LinBox
 
 #endif // __LINBOX_apply_H
 
-
 // Local Variables:
 // mode: C++
-// tab-width: 8
+// tab-width: 4
 // indent-tabs-mode: nil
-// c-basic-offset: 8
+// c-basic-offset: 4
 // End:
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
